package org.framework.lazy.cloud.network.heartbeat.server.standalone.application.impl;


import org.framework.lazy.cloud.network.heartbeat.server.properties.ServerNodeProperties;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.application.LazyClientStatsChangeApplication;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.domain.model.netty.client.state.LazyNettyClientState;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.domain.model.netty.client.state.LazyNettyClientStateRepository;
import org.wu.framework.database.lazy.web.plus.stereotype.LazyApplication;
import lombok.extern.slf4j.Slf4j;
import org.framework.lazy.cloud.network.heartbeat.common.constant.ClientConfigKeyUtils;
import org.framework.lazy.cloud.network.heartbeat.common.enums.NettyClientStatus;


@Slf4j
@LazyApplication
public class LazyClientStatsChangeApplicationImpl implements LazyClientStatsChangeApplication {

    private final LazyNettyClientStateRepository lazyNettyClientStateRepository;
    private final ServerNodeProperties serverNodeProperties;


    public LazyClientStatsChangeApplicationImpl(LazyNettyClientStateRepository lazyNettyClientStateRepository,
                                                ServerNodeProperties serverNodeProperties) {

        this.lazyNettyClientStateRepository = lazyNettyClientStateRepository;
        this.serverNodeProperties = serverNodeProperties;
    }


    /**
     * 客户端在线
     *
     * @param clientId 客户端ID
     */
    @Override
    public void clientOnLine(String clientId) {
        // 如果可以已经在线状态不推送
        String clientStatusKey = ClientConfigKeyUtils.getClientStatusKey(clientId);
//        stringRedisTemplate.opsForValue().set(clientStatusKey, NettyClientStatus.ON_LINE.name());
        LazyNettyClientState lazyNettyClientState = new LazyNettyClientState();
        lazyNettyClientState.setClientId(clientId);
        lazyNettyClientState.setOnLineState(NettyClientStatus.ON_LINE);
        String serverId = serverNodeProperties.getNodeId();
        lazyNettyClientState.setServerId(serverId);
        lazyNettyClientStateRepository.updateOnLIneState(lazyNettyClientState);
        // 触发暂存扫描
//        ClientOnLineState clientOnLineState = new ClientOnLineState();
//        clientOnLineState.setClientId(clientId);
//        clientOnLineState.setOnLineState(NettyClientStatus.ON_LINE.name());
//        stringRedisTemplate.convertAndSend(REDIS_CLIENT_ONLINE_OR_OFFLINE_CHANNEL,clientOnLineState);
    }

    /**
     * 客户端离线
     *
     * @param clientId 客户端ID
     */
    @Override
    public void clientOffLine(String clientId) {
        // 如果可以已经在线状态不推送
        String clientStatusKey = ClientConfigKeyUtils.getClientStatusKey(clientId);
//        stringRedisTemplate.opsForValue().set(clientStatusKey, NettyClientStatus.OFF_LINE.name());
        // 修改客户端状态 离线
        LazyNettyClientState lazyNettyClientState = new LazyNettyClientState();
        lazyNettyClientState.setClientId(clientId);
        lazyNettyClientState.setOnLineState(NettyClientStatus.OFF_LINE);
        lazyNettyClientState.setStagingState("OPENED");
        String serverId = serverNodeProperties.getNodeId();
        lazyNettyClientState.setServerId(serverId);
        lazyNettyClientStateRepository.updateOnLIneState(lazyNettyClientState);
//        // 触发暂存扫描
//        ClientOnLineState clientOnLineState = new ClientOnLineState();
//        clientOnLineState.setClientId(clientId);
//        clientOnLineState.setOnLineState(NettyClientStatus.OFF_LINE.name());
//        stringRedisTemplate.convertAndSend(REDIS_CLIENT_ONLINE_OR_OFFLINE_CHANNEL,clientOnLineState);

    }

    /**
     * 客户端暂存关闭
     *
     * @param clientId 客户端ID
     */
    @Override
    public void stagingClosed(String clientId) {
        LazyNettyClientState lazyNettyClientState = new LazyNettyClientState();
        lazyNettyClientState.setClientId(clientId);
        lazyNettyClientState.setStagingState("CLOSED");
        String serverId = serverNodeProperties.getNodeId();
        lazyNettyClientState.setServerId(serverId);
        lazyNettyClientStateRepository.updateStagingState(lazyNettyClientState);
    }

    /**
     * 客户端暂存开启
     *
     * @param clientId 客户端ID
     */
    @Override
    public void stagingOpened(String clientId) {
        LazyNettyClientState lazyNettyClientState = new LazyNettyClientState();
        lazyNettyClientState.setClientId(clientId);
        lazyNettyClientState.setStagingState("OPENED");
        String serverId = serverNodeProperties.getNodeId();
        lazyNettyClientState.setServerId(serverId);
        lazyNettyClientStateRepository.updateStagingState(lazyNettyClientState);
    }
}
